<template>
	<div>
		<el-form ref="ruleFormRef" :model="ruleForm" status-icon label-width="20px" class="topTitle">
			<el-row>
				<el-col :span="4">
					<el-form-item size="default">
						<el-input v-model="ruleForm.searchParams.indexNum" placeholder="请输入目标指标" />
					</el-form-item>
				</el-col>
				<!-- <el-col :span="4">
				<el-form-item>
					<el-input v-model="ruleForm.checkPass" placeholder="目标指标编号" />
				</el-form-item>
			</el-col> -->
				<el-col :span="4">
					<el-form-item>
						<el-button size="default" type="primary" @click="listApi">查询</el-button>
						<el-button size="default" @click="resetForm">重置</el-button>
					</el-form-item>
				</el-col>
			</el-row>
		</el-form>
		<div class="minCenter">
			<div class="btns">
				<div>
					<el-button size="default" type="primary" :icon="Plus" @click="openD('新建')">新建</el-button>
				</div>
				<div>
					<!-- <el-button size="default" :icon="Refresh"></el-button> -->
				</div>
			</div>
			<el-table ref="multipleTableRef" :data="tableData" style="width: 100%">
				<el-table-column label="序号" align="center" type="index" width="70" />
				<el-table-column label="安全目标指标" align="center" property="qName" sortable />
				<el-table-column property="indexNum" align="center" label="考核指标编号" sortable />
				<el-table-column property="year" label="年度" align="center" sortable show-overflow-tooltip />
				<el-table-column property="value" label="指标值" align="center" sortable show-overflow-tooltip />
				<el-table-column label="操作" align="center" width="300" sortable show-overflow-tooltip>
					<template #default="scope">
						<el-button link type="primary" size="default" :icon="View" @click="openD('查看', scope.row.id)">查看</el-button>
						<el-button link type="primary" size="default" :icon="View" @click="openD('修改', scope.row.id)">修改</el-button>
						<el-button link type="primary" size="default" :icon="Delete" @click="onDelete(scope.row.id)">删除</el-button>
					</template>
				</el-table-column>
			</el-table>
			<div class="pages">
				<el-pagination
					v-model:currentPage="currentPage4"
					v-model:page-size="pageSize4"
					:page-sizes="[10, 20, 30, 40]"
					layout="total, sizes, prev, pager, next, jumper"
					:total="total"
					@size-change="handleSizeChange"
					@current-change="handleCurrentChange"
				/>
			</div>
			<Dailog ref="openAdd"></Dailog>
		</div>
	</div>
</template>
<script lang="ts">
import Dailog from './component/Dailog.vue';
import { ref, toRefs, reactive, onMounted, defineComponent } from 'vue';
import { ElMessageBox, ElMessage, ElButton, ElInput, TabsPaneContext, FormInstance } from 'element-plus';
import { Plus, Delete, Upload, Download, Refresh, View } from '@element-plus/icons-vue';
import { goalManagementApi } from '/@/api/goalManagement';
import type { TableColumnCtx } from 'element-plus/es/components/table/src/table-column/defaults';
export default defineComponent({
	components: { ElButton, ElInput, Dailog },
	setup() {
		// 搜索条件
		const ruleForm = reactive({
			pageSize: 10,
			pageIndex: 1,
			searchParams: {
				qName: '', ////安全目标指标
				indexNum: '', ////目标指标编号
				targetType: '1', ////指标类型 1:年指标 2:月指标
				divideStatus: '', ////分解状态 1:已分解 2:未分解
			},
		});
		// 重置
		const resetForm = () => {
			ruleForm.searchParams.qName = '';
			ruleForm.searchParams.indexNum = '';
		};
		const listApi = () => {
			goalManagementApi()
				.getTargetMngList(ruleForm)
				.then((res) => {
					if (res.data.code == 200) {
						tableData.value = res.data.data;
						currentPage4.value = res.data.pageIndex;
						pageSize4.value = res.data.pageSize;
						total.value = res.data.total;
					} else {
						ElMessage.error(res.data.msg);
					}
				});
		};
		//
		const handleClick = (val: any) => {
			let targetType = JSON.parse(JSON.stringify(val));
			ruleForm.searchParams.targetType = targetType.paneName;
			listApi();
		};
		onMounted(() => {
			listApi();
		});
		const onAddorUpdata = () => {
			listApi();
		};
		// 表格
		const tableData = ref();
		const currentPage4 = ref();
		const pageSize4 = ref();
		const total = ref();
		const handleSizeChange = (val: number) => {
			// console.log(`${val} items per page`);
			ruleForm.pageSize = val;
			listApi();
		};
		const handleCurrentChange = (val: number) => {
			// console.log(`current page: ${val}`);
			ruleForm.pageIndex = val;
			listApi();
		};
			// 删除
		const onDelete = (id: number) => {
			var arr=[]
			arr.push(id)
			ElMessageBox.confirm('确定删除所选项吗?', 'Warning', {
				confirmButtonText: '确定',
				cancelButtonText: '取消',
				type: 'warning',
			})
				.then(() => {
					goalManagementApi()
						.getTargetMngDelete(arr)
						.then((res) => {
							if (res.data.code == 200) {
								ElMessage({
									message: res.data.msg,
									type: 'success',
								});
								listApi();
							} else {
								ElMessage.error(res.data.msg);
							}
						});
				})
				.catch(() => {
					ElMessage({
						type: 'info',
						message: 'Delete canceled',
					});
				});
		};
		// 弹窗
		const openAdd = ref();
		const openD = (title: String, id: number) => {
			openAdd.value.openDailog(title, ruleForm.searchParams.targetType, id);
		};

		return {
			listApi,
			ruleForm,
			resetForm,
			handleClick,
			tableData,
			currentPage4,
			pageSize4,
			handleSizeChange,
			handleCurrentChange,
			onAddorUpdata,
			total,
			openAdd,
			openD,
			onDelete,
			Plus,
			Delete,
			Upload,
			Download,
			Refresh,
			View,
		};
	},
});
</script>
<style scoped>
.topTitle {
	background-color: #fff;
	padding: 20px 0px 20px 0px;
	margin-bottom: 10px;
}
.minCenter {
	width: 100%;
	background-color: #fff;
	margin-top: 10px;
	padding: 0 20px;
}
.btns {
	padding: 10px 0px 10px 0px;
	display: flex;
	justify-content: space-between;
}
.pages {
	padding: 20px 0;
	display: flex;
	justify-content: right;
}
</style>